Module request

Module request 

Request conversion: Responses API → Chat API.

Structs

ToolSearchContext
Context for tracking tool search state during input conversion.

Enums

ToolPriority
Tool priority when merging predefined tools with searched tools.

Functions

convert_input_to_messages
Convert input (with optional instructions) to Chat messages.
convert_tool_choice
Convert Responses API tool choice to Chat API tool choice.
convert_tools
Convert Responses API tools to Chat API tools.
extract_content
Extract text content from Response API content.
response_to_chat
Convert a Responses API request to a Chat API request.