Request conversion: Responses API → Chat API.
Structs
- Tool
Search Context - Context for tracking tool search state during input conversion.
Enums
- Tool
Priority - Tool priority when merging predefined tools with searched tools.
Functions
- convert_
input_ to_ messages - Convert input (with optional instructions) to Chat messages.
- convert_
tool_ choice - Convert Responses API tool choice to Chat API tool choice.
- convert_
tools - Convert Responses API tools to Chat API tools.
- extract_
content - Extract text content from Response API content.
- response_
to_ chat - Convert a Responses API request to a Chat API request.